@@ -91,15 +91,21 @@ class Diff2HTMLTransform(Transform):
         self._done_cb = self.stop_chunk
         self._continue_cb = self.diff_line
 
-    def stop_chunk(self, trdata, w):
-        w(u'</pre>\n')
+    def inc_counter(self, trdata):
         try:
             trdata.insert_points_count += 1
             ipid = trdata.insert_points_count
         except AttributeError:
             ipid = trdata.insert_points_count = 1
-        self._ipcb(unicode(ipid), trdata, w)
+        return ipid
+
+    def stop_chunk(self, trdata, w):
+        w(u'</pre>\n')
+        ipid = self.inc_counter(trdata)
+        self._ipcb(ipid, trdata, w)
         w(u'</div>\n')
 
     def stop_comment(self, trdata, w):
+        ipid = self.inc_counter(trdata)
+        self._ipcb(ipid, trdata, w)
         w(u'</div>\n')
