@@ -144,25 +144,25 @@ class SearchPatchStateInstructionOp(hook.DataOperationMixIn,
                          if w.lower() in interestingwords]
                 if len(words) < 2:
                     continue
-                if words[1] == 'ready' and words[0] in readycandidates:
+                if words[1] in ('ready', 'pending') and words[0] in readycandidates:
                     fire(readycandidates.pop(words[0]),
                          'ask review', u'review asked by %s in %s' % (
                              rev.author, rev.changeset or rev.revision))
-                elif words[0] == 'refuse' and words[1] in pendingcandidates:
+                elif words[0] in ('refuse', 'refused') and words[1] in pendingcandidates:
                     patch = pendingcandidates.pop(words[1])
                     fire(patch, 'ask rework', u'refused by %s in %s' % (
                         rev.author, rev.changeset or rev.revision))
-                elif words[0] == 'reject' and words[1] in rejectcandidates:
+                elif words[0] in ('reject', 'rejected') and words[1] in rejectcandidates:
                     patch = rejectcandidates.pop(words[1])
                     fire(patch, 'reject', u'rejected by %s in %s' % (
                         rev.author, rev.changeset or rev.revision))
                     self.ensure_wont_be_deleted(patch)
-                elif words[0] == 'fold' and words[1] in rejectcandidates:
+                elif words[0] in ('fold', 'folded') and words[1] in rejectcandidates:
                     patch = rejectcandidates.pop(words[1])
                     fire(patch, 'fold', u'folded by %s in %s' % (
                         rev.author, rev.changeset or rev.revision))
                     self.ensure_wont_be_deleted(patch)
-                elif words[0] == 'applied' and words[1] in rejectcandidates:
+                elif words[0] in ('apply', 'applied') and words[1] in rejectcandidates:
                     patch = rejectcandidates.pop(words[1])
                     fire(patch, 'apply', u'applied by %s' % rev.author)
                     self.ensure_wont_be_deleted(patch)
