@@ -52,9 +52,8 @@ pwf.add_transition(_('reject'), (inprogress, pending, deleted, reviewed), reject
 # internal transition, not available through the ui
 # XXX we've to put 'managers' group since transition without groups
 # nor condition are fireable by anyone...
-pwf.add_transition(_('file deleted'), (inprogress, pending), deleted,
-                   ('managers', 'committers',),
-                   'X patch_repository R, R repository_committer U')
+pwf.add_transition(_('file deleted'), (inprogress, pending, reviewed), deleted,
+                   ('managers',))
 # in case hooks following patch state made a mistake, we should be able to
 # reopen the patch
 pwf.add_transition(_('reopen'), deleted, inprogress,
