@@ -25,10 +25,11 @@ from cubicweb.selectors import (is_instance, relation_possible,
 from cubicweb.view import EntityView
 from cubicweb.uilib import js
 from cubicweb.web import uicfg, component, form, formwidgets as wdg
-from cubicweb.web.views import workflow, idownloadable, ajaxedit
+from cubicweb.web.views import (workflow, idownloadable, ajaxedit,
+                                forms, formrenderers)
 
 from cubes.comment import views as comment
-
+from cubes.vcreview.site_cubicweb import COMPONENT_CONTEXT
 
 _afs = uicfg.autoform_section
 _affk = uicfg.autoform_field_kwargs
@@ -73,8 +74,7 @@ class AddActivityFormView(form.FormViewMixIn, EntityView):
                                  ('description', 'subject'),
                                  ('has_activity', 'object'))))
         self.w(u'<div id="activity%sSlot">' % container.eid)
-        form.render(w=self.w, main_form_title=u'', display_label=False,
-                    formvalues=formvalues)
+        form.render(w=self.w, main_form_title=u'', formvalues=formvalues)
         self.w(u'</div>')
 
 
@@ -103,7 +103,7 @@ class ActivityComponent(component.EntityCtxComponent):
             w(u'(<a href="%s">%s</a>)' % (xml_escape(url), req._('add a task')))
 
     existing_tasks_rql = (
-        u'Any T,TD,TS,TCD,U,T, TT,TDF,UL,UF,US ORDERBY TCD DESC WHERE '
+        u'Any T,TD,T,TCD,U, TS,TT,TDF,UL,UF,US ORDERBY TCD DESC WHERE '
         'X has_activity T, T description TD, T in_state TS,'
         'T creation_date TCD, T created_by U?,'
         'T title TT, T description_format TDF, '
@@ -118,15 +118,15 @@ class ActivityComponent(component.EntityCtxComponent):
                                    self._cw._('detail'),
                                    self._cw.__('in_state'),
                                    self._cw.__('creation_date'),
-                                   self._cw.__('created_by'),
-                                   self._cw.__('todo_by'),],
-                          cellvids={5: 'vcreview.task-todoers'})
+                                   self._cw.__('created_by'),],
+                          cellvids={0: 'vcreview.task-link',
+                                    2: 'vcreview.task-state'})
 
 
 class PatchActivityComponent(ActivityComponent):
     __select__ = ActivityComponent.__select__ & is_instance('Patch')
     existing_tasks_rql = (
-        u'Any T,TD,TS,TCD,U,T, TT,TDF,UL,UF,US ORDERBY TCD DESC '
+        u'Any T,TD,T,TCD,U, TS,TT,TDF,UL,UF,US ORDERBY TCD DESC '
         'WITH T,TD,TS,TCD,U,TT,TDF,UL,UF,US BEING ('
         '(Any T,TD,TS,TCD,U,TT,TDF,UL,UF,US WHERE '
         'X has_activity T, T description TD, T in_state TS,'
@@ -146,9 +146,72 @@ workflow.WFHistoryVComponent.order = 10
 ActivityComponent.order = 20
 comment.CommentSectionVComponent.order = 30
 
-class TaskTodoersView(EntityView):
-    __regid__ = 'vcreview.task-todoers'
+
+class TaskDoneForm(forms.CompositeEntityForm):
+    __regid__ = 'taskdone'
+    form_renderer_id = 'onebutton'
+    form_buttons = [wdg.SubmitButton(label=_('mark as done'))]
+    cssclass = 'inline'
+    @property
+    def domid(self):
+        return 'taskdone%s' % self.edited_entity.eid
+
+
+class MyFormRenderer(formrenderers.FormRenderer):
+    __regid__ = 'onebutton'
+    display_progress_div = False
+
+    def render_buttons(self, w, form):
+        for button in form.form_buttons:
+            w(button.render(form))
+
+
+class TaskStateView(form.FormViewMixIn, EntityView):
+    __regid__ = 'vcreview.task-state'
     __select__ = is_instance('Task')
 
     def entity_call(self, entity):
-        self.wview('csv', entity.related('todo_by'), 'null')
+        self._cw.add_css('cubes.vcreview.css')
+        iwf = entity.cw_adapt_to('IWorkflowable')
+        self.w(iwf.printable_state)
+        if iwf.state != 'todo':
+            return
+        for transition in iwf.possible_transitions():
+            if transition.name == 'done':
+                break
+        else:
+            return # task workflow changed or no permission to go through the transtion
+        form = self.get_form(entity, transition)
+        form.render(w=self.w)
+
+    def get_form(self, entity, transition, **kwargs):
+        form = self._cw.vreg['forms'].select(
+            'taskdone', self._cw, entity=entity, transition=transition,
+            redirect_path=self._cw.relative_path(), **kwargs)
+        trinfo = self._cw.vreg['etypes'].etype_class('TrInfo')(self._cw)
+        trinfo.eid = self._cw.varmaker.next()
+        subform = self._cw.vreg['forms'].select(
+            'edition', self._cw, entity=trinfo, mainform=False,
+            display_fields=[('wf_info_for', 'subject'),
+                            ('by_transition', 'subject')])
+        subform.field_by_name('wf_info_for', 'subject').value = entity.eid
+        trfield = subform.field_by_name('by_transition', 'subject')
+        trfield.widget = wdg.HiddenInput()
+        trfield.value = transition.eid
+        form.add_subform(subform)
+        return form
+
+
+class TaskLinkView(form.FormViewMixIn, EntityView):
+    __regid__ = 'vcreview.task-link'
+    __select__ = is_instance('Task')
+    def entity_call(self, entity):
+        self.w(entity.view('incontext'))
+        if not self._cw.json_request and \
+               entity.reverse_has_activity[0].__regid__ == 'InsertionPoint':
+            ip = entity.reverse_has_activity[0]
+            purl = ip.parent.absolute_url()
+            if purl != self._cw.url(includeparams=False):
+                url = u'%s#%s%s' % (purl, COMPONENT_CONTEXT, ip.eid)
+                self.w(u' (<a href="%s">%s</a>)' % (url, self._cw._('see in context')))
+
