@@ -29,6 +29,7 @@ from cubicweb.web.views import primary, ibreadcrumbs
 
 from cubes.vcsfile.views import primary as vcsfile
 from cubes.vcreview.views import patch_states_rql
+from cubes.vcreview.site_cubicweb import COMPONENT_CONTEXT
 
 _pvs = uicfg.primaryview_section
 _pvdc = uicfg.primaryview_display_ctrl
@@ -162,6 +163,18 @@ class RepositoryPatchesTable(EntityView):
         rset = self._cw.execute(rql, {'x': entity.eid})
         self.wview('vcreview.patches.table', rset, 'noresult', displayfilter=True)
 
+# task primary view ############################################################
+
+_pvs.tag_object_of(('*', 'has_activity', 'Task'), 'attributes')
+
+class InsertionPointInContextView(EntityView):
+    __regid__ = 'incontext'
+    __select__ = is_instance('InsertionPoint')
+    def entity_call(self, entity):
+        purl = entity.parent.absolute_url()
+        url = '%s#%s%s' % (purl, COMPONENT_CONTEXT, entity.eid)
+        self.w(u'<a href="%s">%s</a>' % (url, entity.parent.dc_title()))
+
 
 # breadcrumbs ##################################################################
 
@@ -189,6 +202,26 @@ class DVCBreadCrumbTextView(ibreadcrumbs.BreadCrumbTextView):
                           entity.revision))
 
 
+class TaskBreadCrumbsAdapter(ibreadcrumbs.IBreadCrumbsAdapter):
+    __select__ = (is_instance('Task')
+                  & score_entity(lambda x: x.reverse_has_activity))
+
+    def parent_entity(self):
+        return self.entity.reverse_has_activity[0]
+
+
+class InsertionPointBreadCrumbsAdapter(ibreadcrumbs.IBreadCrumbsAdapter):
+    __select__ = is_instance('InsertionPoint')
+
+    def parent_entity(self):
+        return self.entity.parent
+
+    def breadcrumbs(self, view=None, recurs=None):
+        path = super(InsertionPointBreadCrumbsAdapter, self).breadcrumbs(
+            view, recurs)
+        return [x for x in path if getattr(x, 'eid', None) != self.entity.eid]
+
+
 def registration_callback(vreg):
     vreg.register_all(globals().values(), __name__, (VCPrimaryView,))
     vreg.register_and_replace(VCPrimaryView, vcsfile.VCPrimaryView)
